@@ -72,7 +72,8 @@ Acme::Claude::Shell::Session - Multi-turn session for Acme::Claude::Shell
 =head1 DESCRIPTION
 
 Runs an interactive REPL using Claude's session() function for multi-turn
-conversations. Claude remembers context from previous commands.
+conversations. Claude remembers context from previous commands, so you can
+say things like "now compress those files" after a find command.
 
 Uses Claude::Agent SDK features:
 
@@ -80,14 +81,51 @@ Uses Claude::Agent SDK features:
 
 =item * C<session()> - Multi-turn conversation with context
 
-=item * SDK MCP tools - execute_command, list_files, read_file
+=item * SDK MCP tools - execute_command, read_file, list_directory, search_files, get_system_info, get_working_directory
 
-=item * Hooks - Safety confirmation before command execution
+=item * Hooks - PreToolUse (audit), PostToolUse (stats), PostToolUseFailure (errors), Stop (statistics), Notification (logging)
 
-=item * CLI utilities - Spinners, menus, and colored output
+=item * CLI utilities - Spinners, menus, colored output
 
 =back
 
+=head2 Attributes
+
+=over 4
+
+=item * C<loop> (required) - IO::Async::Loop instance
+
+=item * C<dry_run> - Preview mode, don't execute commands (default: 0)
+
+=item * C<safe_mode> - Confirm dangerous commands (default: 1)
+
+=item * C<working_dir> - Starting directory (default: '.')
+
+=item * C<colorful> - Use colored output (default: 1)
+
+=item * C<model> - Claude model to use (optional)
+
+=back
+
+=head2 Built-in Commands
+
+=over 4
+
+=item * C<help> - Show help message
+
+=item * C<history> - Select and re-run previous commands
+
+=item * C<clear> - Clear the screen
+
+=item * C<exit> / C<quit> - Exit the shell
+
+=back
+
+=head2 History
+
+Command history is persisted to C<~/.acme_claude_shell_history> and loaded
+on startup. Maximum 1000 lines are kept.
+
 =cut
 
 # Query cursor row position via /dev/tty (works even after Term::ReadLine)
